@@ -93,6 +93,8 @@ import com.microsoft.windowsazure.services.blob.BlobContract;
 import com.microsoft.windowsazure.services.blob.BlobService;
 import com.microsoft.windowsazure.services.blob.models.CreateBlobOptions;
 import com.microsoft.windowsazure.services.blob.models.GetBlobResult;
+import com.microsoft.windowsazure.services.blob.models.ListContainersOptions;
+import com.microsoft.windowsazure.services.blob.models.ListContainersResult.Container;
 
 @Transactional(Transactional.TransactionType.Supported)
 public class AzureResourceManagement implements IResourceManagement, AzureConstants {
@@ -295,8 +297,11 @@ public class AzureResourceManagement implements IResourceManagement, AzureConsta
         	Configuration config = getConfiguration();
 			ManagementClient managementClient = ManagementService.create(config);
 			ComputeManagementClient computeManagementClient = ComputeManagementService.create(config);
+			StorageManagementClient storageManagementClient = StorageManagementService.create(config);
 
 			HostedServiceOperations hostedServicesOperations = computeManagementClient.getHostedServicesOperations();
+			StorageAccountOperations storageAccountOperations = storageManagementClient.getStorageAccountsOperations();
+			
 			DeploymentOperations deploymentOperations = computeManagementClient.getDeploymentsOperations();
 			AffinityGroupOperations affinityGroupOperations = managementClient.getAffinityGroupsOperations();
 			AffinityGroupListResponse affinityGroupListResponse = affinityGroupOperations.list();
@@ -323,9 +328,45 @@ public class AzureResourceManagement implements IResourceManagement, AzureConsta
 									}
 								}
 								if(roleinstance.getRoleName().equalsIgnoreCase(role.getRoleName())){
+									logger.debug("getInstances() : roleinstance.getRoleName() = " + roleinstance.getRoleName() + ", role.getRoleName() = " + role.getRoleName());
 									if(!cond.isExist(role.getRoleName(),getRegion().getName(),getCledential().getAccessKey())){
+										Tag tag;
+										
+										AzureUtil.AzureServiceRequestFilter request = new AzureUtil.AzureServiceRequestFilter();
+										AzureUtil.AzureServiceResponseFilter response = new AzureUtil.AzureServiceResponseFilter();
+										
+										String storageAccountName = AzureUtil.getStorageAccountNameFromVHD(role.getOSVirtualHardDisk().getMediaLink().toString());
+										String containerName = AzureUtil.getContainerNameFromVHD(role.getOSVirtualHardDisk().getMediaLink().toString());
+										
+										Configuration blobconfig = null;
+										blobconfig = AzureUtil.getBlobConfiguration(storageAccountName, storageAccountOperations.getKeys(storageAccountName).getPrimaryKey());
+										BlobContract blobContract = BlobService.create(blobconfig).withRequestFilterLast(request).withResponseFilterLast(response);
+										ListContainersOptions opt = new ListContainersOptions();
+										opt.setIncludeMetadata(true);
+										List<Container> containers = blobContract.listContainers(opt).getContainers();
 										List<Tag> tags = new ArrayList<>();
-										instances.add(convertInstance(hostService,role,roleinstance,slot.toString(),tags));
+										for(Container container:containers){
+											if(container.getName().equals(containerName)){
+												for(String value:container.getMetadata().values()){
+													if(value.startsWith(role.getRoleName()+"=")){
+														tag = new Tag();
+														tag.setKey("hinemosAssignScopeId");
+														tag.setValue(value.substring(role.getRoleName().length()+1));
+														tags.add(tag);
+													}
+												}
+											}
+										}
+										boolean exist = false;
+										for(Instance instance:instances){
+											if(instance.getImageId().equals(role.getRoleName())){
+												instance.setTags(tags);
+												exist = true;
+											}
+										}
+										if(!exist){
+											instances.add(convertInstance(hostService,role,roleinstance,slot.toString(),tags));
+										}
 									}
 								}
 							}
